@@ -727,178 +727,176 @@ def metadata_extraction (df_users):
 
 def text_tweets_features_extraction(data_tweets):
    
-	seasonalityDF = []
-	tweets_urlDF = []
-	mentionsDF = []
-	text_tweetsDF = []
-	fav_twDF= []
-	ret_twDF = []
-	ret_twDF_list = []
-	fav_twDF_list = []
-	ntwPro_DF= []
-	RT_tw = []
-	minu_tw = []
-	minu_tw_answer = []
-	tw_duplicated = []
-	duplicated = []
-	tw_per_day_list= []
-	screen_name_mention_user = []
-	tweets = []
-	tweets_url = 0
-	num_tw_day = 1
-	is_RT=0
-	is_RT_list= []
-	screen_name_mention = []
-	RT = []
-	retweet_list = []
-	favorite_list = []
-	mentions = 0
-	time_btw_tw = []
-	tw_answer = []
-	num_tw_days = []
-	text_duplicated = []
-	tw_day_list = []
-	text_tweets_day = []
-	text_tweets_days = []
-	text_tweets_days_list = []
-	#Almacenar la fecha entera de los tweets para si hay que consultar las horas de ese dia
-	tweet_date_day = []
-	tweet_date_days = []
-	tweet_date_days_list = []
-	lang_text_tweet = list(data_tweets["lang_tw"])
-	text_tweets_user= list(data_tweets["text"])
-	favorites= list(data_tweets["favorites"])
-	retweets = list(data_tweets["retweets"])
-	tweets_date= pd.to_datetime(data_tweets["created_at_tw"])
-	for j in range(len(text_tweets_user)): #Comprobamos cuantos tweets han sido escritos por el usuario 
-		if(text_tweets_user[j].startswith('RT',0)):
-			RT.append(text_tweets_user[j])
-			is_RT = 1
-		else:
-			is_RT=0          
-			#Tweets with url from users
-			if "http" in text_tweets_user[j]:
-				tweets_url = tweets_url + 1
-			#Tweets with mentions from users
-			if "@" in text_tweets_user[j]:
-				mentions = mentions + 1                        
-			else:
-				#Time of the answer of a tweet(tw --> @)
-				if(j!=(len(text_tweets_user)-1)):
-					if ("@" in text_tweets_user[j+1]):
-						tw_answer.append((tweets_date[j] - tweets_date[j+1]) / np.timedelta64(1,'m'))
-				#Found duplicated tweets where the only change the photo  that the users publish
-				text_sinHttp = " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split()))
-				text_sinMencion = " ".join(filter(lambda x:x[0]!='@', text_sinHttp.split()))
-				text_duplicated.append(text_sinMencion)
-			tweets.append({"text":text_tweets_user[j], "lang": lang_text_tweet[j], "RT": 0})
-			retweet_list.append(int(retweets[j]))
-			favorite_list.append(int(favorites[j]))
-		is_RT_list.append(is_RT)                                
-		if(j!=0):
-			#Time between tweets (RT + propios)
-			time_btw_tw.append((tweets_date[j-1] - tweets_date[j]) / np.timedelta64(1,'m'))
-			#Found if tweets are the same day
-			#Second condition if all the tweets are the same day          
-			if((tweets_date[j-1].date() == tweets_date[j].date()) & (j!=(len(text_tweets_user)-1))):                            
-				
-				#Create a list with the tweets of a day
-				text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
-				text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split())),"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
-				tweet_date_day.append(tweets_date[j-1])
-				tweet_date_day.append(tweets_date[j])                         
-			else:
-				if(j==(len(text_tweets_user)-1)):                  
-					if(tweets_date[j-1].date() == tweets_date[j].date()):                     
-						text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
-						text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split())),"lang": lang_text_tweet[j], "RT": is_RT_list[j]})           
-						tweet_date_day.append(tweets_date[j-1])
-						tweet_date_day.append(tweets_date[j])
-						                     
-						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-						num_tw_days.append(len(list(dict.fromkeys(tweet_date_day))))
-						num_tw_day = 1 
-						text_tweets_day = []
-						tweet_date_day = []
-					else:                      
-						text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})				                                   
-						tweet_date_day.append(tweets_date[j-1]) 
-						num_tw_days.append(1)                     
-						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]])
-						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-						text_tweets_day = []
-						tweet_date_day = []                      
-						tweet_date_day.append(tweets_date[j])                     
-						text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split())),"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
-						num_tw_days.append(1)
-						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-						num_tw_day = 1 
-						text_tweets_day = []
-						tweet_date_day = []                      
-				else:
-					if(num_tw_day ==1):
-						text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})	
-						tweet_date_day.append(tweets_date[j-1])                  
-					text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-					tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-					num_tw_days.append(len(list(dict.fromkeys(tweet_date_day))))
-					num_tw_day = 1 
-					text_tweets_day = []
-					tweet_date_day = []
-		if "@" in (text_tweets_user[j]):
-			split_text = text_tweets_user[j].split()
-			check = "@"
-			screen_name_mention1 = [idx for idx in split_text if idx.lower().startswith(check.lower())] 
-			if not screen_name_mention1:
-				screen_name_mention.append(["Empty"])
-			else:
-				screen_name_mention1 = re.sub("[\[\]\'\"!@?¿#$:….,]", '',str(screen_name_mention1)).split(", ")
-				if(text_tweets_user[j].startswith('RT',0)):
-					screen_name_mention.append([screen_name_mention1[0]])                    
-				else:
-					screen_name_mention.append(screen_name_mention1)
-		else:
-			screen_name_mention.append(["Empty"])
+    seasonalityDF = []
+    tweets_urlDF = []
+    mentionsDF = []
+    text_tweetsDF = []
+    fav_twDF= []
+    ret_twDF = []
+    ret_twDF_list = []
+    fav_twDF_list = []
+    ntwPro_DF= []
+    RT_tw = []
+    minu_tw = []
+    minu_tw_answer = []
+    tw_duplicated = []
+    duplicated = []
+    tw_per_day_list= []
+    screen_name_mention_user = []
+    tweets = []
+    tweets_url = 0
+    num_tw_day = 1
+    is_RT=0
+    is_RT_list= []
+    screen_name_mention = []
+    RT = []
+    retweet_list = []
+    favorite_list = []
+    mentions = 0
+    time_btw_tw = []
+    tw_answer = []
+    num_tw_days = []
+    text_duplicated = []
+    tw_day_list = []
+    text_tweets_day = []
+    text_tweets_days = []
+    text_tweets_days_list = []
+    #Almacenar la fecha entera de los tweets para si hay que consultar las horas de ese dia
+    tweet_date_day = []
+    tweet_date_days = []
+    tweet_date_days_list = []
+    lang_text_tweet = list(data_tweets["lang_tw"])
+    text_tweets_user= list(data_tweets["text"])
+    favorites= list(data_tweets["favorites"])
+    retweets = list(data_tweets["retweets"])
+    tweets_date= pd.to_datetime(data_tweets["created_at_tw"])
+    for j in range(len(text_tweets_user)): #Comprobamos cuantos tweets han sido escritos por el usuario 
+      if (text_tweets_user[j].startswith('RT',0)):
+        RT.append(text_tweets_user[j])
+        is_RT = 1
+      else:
+        is_RT=0          
+        #Tweets with url from users
+        if "http" in text_tweets_user[j]:
+          tweets_url = tweets_url + 1
+        #Tweets with mentions from users
+        if "@" in text_tweets_user[j]:
+          mentions = mentions + 1                        
+        else:
+          #Time of the answer of a tweet(tw --> @)
+          if(j!=(len(text_tweets_user)-1)):
+            if ("@" in text_tweets_user[j+1]):
+              tw_answer.append((tweets_date[j] - tweets_date[j+1]) / np.timedelta64(1,'m'))
+          #Found duplicated tweets where the only change the photo  that the users publish
+          text_sinHttp = " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split()))
+          text_sinMencion = " ".join(filter(lambda x:x[0]!='@', text_sinHttp.split()))
+          text_duplicated.append(text_sinMencion)
+        tweets.append({"text":text_tweets_user[j], "lang": lang_text_tweet[j], "RT": 0})
+        retweet_list.append(int(retweets[j]))
+        favorite_list.append(int(favorites[j]))
+      is_RT_list.append(is_RT)                                
+      if (j!=0):
+        #Time between tweets (RT + propios)
+        time_btw_tw.append((tweets_date[j-1] - tweets_date[j]) / np.timedelta64(1,'m'))
+        #Found if tweets are the same day
+        #Second condition if all the tweets are the same day          
+        if ((tweets_date[j-1].date() == tweets_date[j].date()) & (j!=(len(text_tweets_user)-1))):                        
+          #Create a list with the tweets of a day
+          text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})             
+          tweet_date_day.append(tweets_date[j-1])
+        else:
+          if (j==(len(text_tweets_user)-1)):                  
+            if (tweets_date[j-1].date() == tweets_date[j].date()):                     
+              text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
+              text_tweets_day.append({"text":  " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split())),"lang": lang_text_tweet[j], "RT": is_RT_list[j]})           
+              tweet_date_day.append(tweets_date[j-1])
+              tweet_date_day.append(tweets_date[j])
+                                  
+              text_tweets_days.append(text_tweets_day)
+              tweet_date_days.append(tweet_date_day)
+              num_tw_days.append(len(tweet_date_day))
+              num_tw_day = 1 
+              text_tweets_day = []
+              tweet_date_day = []
+            else:                      
+              text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})				                                   
+              tweet_date_day.append(tweets_date[j-1]) 
+              num_tw_days.append(1)                     
+              text_tweets_days.append(text_tweets_day)
+              tweet_date_days.append(tweet_date_day)
+              text_tweets_day = []
+              tweet_date_day = []                      
+              tweet_date_day.append(tweets_date[j])                     
+              text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
+              num_tw_days.append(1)
+              text_tweets_days.append(text_tweets_day)
+              tweet_date_days.append(tweet_date_day)
+              num_tw_day = 1 
+              text_tweets_day = []
+              tweet_date_day = []                      
+          else:
+            if(num_tw_day ==1):
+              text_tweets_day.append({"text": " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j-1].split())),"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})	
+              tweet_date_day.append(tweets_date[j-1])                  
+            text_tweets_days.append(text_tweets_day)
+            tweet_date_days.append(tweet_date_day)
+            num_tw_days.append(len(tweet_date_day))
+            num_tw_day = 1 
+            text_tweets_day = []
+            tweet_date_day = []
+      if "@" in (text_tweets_user[j]):
+        split_text = text_tweets_user[j].split()
+        check = "@"
+        screen_name_mention1 = [idx for idx in split_text if idx.lower().startswith(check.lower())] 
+        if not screen_name_mention1:
+          screen_name_mention.append(["Empty"])
+        else:
+          screen_name_mention1 = re.sub("[\[\]\'\"!@?¿#$:….,]", '',str(screen_name_mention1)).split(", ")
+          if(text_tweets_user[j].startswith('RT',0)):
+            screen_name_mention.append([screen_name_mention1[0]])                    
+          else:
+            screen_name_mention.append(screen_name_mention1)
+      else:
+        screen_name_mention.append(["Empty"])
 
-	if(len(set(text_duplicated)) != len((text_duplicated))):
-		duplicated.append(len(text_duplicated) - len(set(text_duplicated)))
-	else:
-		duplicated.append(0)
-    
-	#Maximun tweets for user
-	if not num_tw_days:
-		text_tweets_days_list.append([{"text":"Empty", "lang":"und","RT":2}])
-		tweet_date_days_list.append(["Empty"])
-		tw_per_day_list.append([0])
-	else:
-		text_tweets_days_list.append(text_tweets_days)
-		tweet_date_days_list.append(tweet_date_days)
-		tw_per_day_list.append(num_tw_days)
+    if(len(set(text_duplicated)) != len((text_duplicated))):
+      duplicated.append(len(text_duplicated) - len(set(text_duplicated)))
+    else:
+      duplicated.append(0)
+      
+    #Maximun tweets for user
+    if not num_tw_days:
+      text_tweets_days_list.append([{"text":"Empty", "lang":"und","RT":2}])
+      tweet_date_days_list.append(["Empty"])
+      tw_per_day_list.append([0])
+    else:
+      text_tweets_days_list.append(text_tweets_days)
+      tweet_date_days_list.append(tweet_date_days)
+      tw_per_day_list.append(num_tw_days)
+
+    tw_day_list.append(list(sorted(set(tweets_date.dt.date), reverse=True)))
+    screen_name_mention_user.append(screen_name_mention)
+    seasonalityDF.append(np.std(time_btw_tw))
+    tweets_urlDF.append(tweets_url)
+    mentionsDF.append(mentions)
+    text_tweetsDF.append(tweets)
+    fav_twDF_list.append(favorite_list)
+    ret_twDF_list.append(retweet_list)
+    fav_twDF.append(int(sum(favorite_list)))
+    ret_twDF.append(int(sum(retweet_list)))
+    ntwPro_DF.append(int(len(tweets)))
+    RT_tw.append(int(len(RT)))
+    minu_tw.append(int(sum(time_btw_tw)))
+    #Time between tweets and its answer
+    if not tw_answer:
+      minu_tw_answer.append(0)
+    else:   
+      minu_tw_answer.append(int(sum(tw_answer))/len(tw_answer))
+          
+    return [screen_name_mention_user,seasonalityDF,tweets_urlDF,mentionsDF,text_tweetsDF,
+        fav_twDF_list,ret_twDF_list,fav_twDF,ret_twDF,RT_tw,ntwPro_DF,minu_tw,tw_per_day_list,
+        text_tweets_days_list,tweet_date_days_list,duplicated,minu_tw_answer,tw_day_list]
 
-	tw_day_list.append(list(sorted(set(tweets_date.dt.date), reverse=True)))
-	screen_name_mention_user.append(screen_name_mention)
-	seasonalityDF.append(np.std(time_btw_tw))
-	tweets_urlDF.append(tweets_url)
-	mentionsDF.append(mentions)
-	text_tweetsDF.append(tweets)
-	fav_twDF_list.append(favorite_list)
-	ret_twDF_list.append(retweet_list)
-	fav_twDF.append(int(sum(favorite_list)))
-	ret_twDF.append(int(sum(retweet_list)))
-	ntwPro_DF.append(int(len(tweets)))
-	RT_tw.append(int(len(RT)))
-	minu_tw.append(int(sum(time_btw_tw)))
-	#Time between tweets and its answer
-	if not tw_answer:
-		minu_tw_answer.append(0)
-	else:   
-		minu_tw_answer.append(int(sum(tw_answer))/len(tw_answer))
-        
-	return [screen_name_mention_user,seasonalityDF,tweets_urlDF,mentionsDF,text_tweetsDF,
-			fav_twDF_list,ret_twDF_list,fav_twDF,ret_twDF,RT_tw,ntwPro_DF,minu_tw,tw_per_day_list,
-			text_tweets_days_list,tweet_date_days_list,duplicated,minu_tw_answer,tw_day_list]
 
 def time_twitter_account(df):
 
@@ -929,7 +927,7 @@ def time_series_tw (df):
 
     #-------------------------------------------Ratios and other advanced features----------------------------------#
 def duplicates_detection(data):
-    data = hour_days_tweets(data)
+    
     data["possible_duplicates"] = 0
     data["close_duplicates"] = 0
     data["group_duplicates"] = 0
@@ -956,17 +954,17 @@ def duplicates_detection(data):
                     for a in range(len(text_1_aux)):
                         aux2 = pd.DataFrame({'text':text_1_aux["text"].iloc[a]})
                         text_1 = text_1.append(aux2, ignore_index=False).reset_index(drop=True)
-                    text_1 = list(itertools.chain(*text_1["text"]))   
-                    text_2 = list(itertools.chain(*data.iloc[i]["text_tweets_days_list"]))               
-                    if "Empty" in text_1:
-                        text_1 = list(filter(("Empty").__ne__, text_1))
-                    if "Empty" in text_2:  
-                        text_2 = list(filter(("Empty").__ne__, text_2))
-                    if "" in text_1:
-                        text_1 = list(filter(("").__ne__, text_1))
-                    if "" in text_2:  
-                        text_2 = list(filter(("").__ne__, text_2))  
-                    comparacion = [item for item in text_2 if item in text_1]
+                    text_1_list = list(itertools.chain(*text_1["text"]))   
+                    text_2_list = list(itertools.chain(*data.iloc[i]["text_tweets_days_list"]))               
+                    if "Empty" in text_1_list:
+                        text_1_list = list(filter(("Empty").__ne__, text_1_list))
+                    if "Empty" in text_2_list:  
+                        text_2_list = list(filter(("Empty").__ne__, text_2_list))
+                    if "" in text_1_list:
+                        text_1_list = list(filter(("").__ne__, text_1_list))
+                    if "" in text_2_list:  
+                        text_2_list = list(filter(("").__ne__, text_2_list))  
+                    comparacion = [item for item in text_2_list if item in text_1_list]                         
                     if len(comparacion) > 0:
                         tw_similarity = len(comparacion)/(data["num_userTw"].iloc[i])
                         if (tw_similarity > 0.00003): 
@@ -985,39 +983,77 @@ def duplicates_detection(data):
                 close_duplicates_list.append("Empty")
     data["close_duplicates"] = close_duplicates_list
     data["group_duplicates"] = group_duplicates_list
-
+    
     duplicate_profiles = data[data["group_duplicates"]!="Empty"].reset_index(drop=True)
+    
+    duplicate_profiles = hour_days_tweets(duplicate_profiles)
+    duplicate_profiles = text_date_tweets_dict(duplicate_profiles)
     group_of_duplicates_list=[]
     for i in range(len(duplicate_profiles)):
         group_of_duplicates_list.append(sorted(duplicate_profiles["group_duplicates"].iloc[i]))
     group_duplicates = list(group_of_duplicates_list for group_of_duplicates_list,_ in itertools.groupby(group_of_duplicates_list))
-    data_group_duplicates = groups_duplicates_detection(group_duplicates,data)
+    data_group_duplicates = groups_duplicates_detection(group_duplicates,duplicate_profiles)
     return duplicate_profiles, data_group_duplicates
 
 def groups_duplicates_detection(group_duplicates,data):
     data_final= {}
-    for i in range(len(group_duplicates)):
-        data_final["Group "+ str(i)]= []
+    number_group = 0
+    for i in range(len(group_duplicates)):        
         
         group_duplicate_tw_day_size = 0
         tw_day_list_size=[] 
+        similar_tw_list = []
         for j in range(len(group_duplicates[i])):                    
-            tw_day_list_size.append(len(data[data["screen_name"]==group_duplicates[i][j]]["tw_day_list"].iloc[0]))    
-            
-        group_duplicate_tw_day_size =  min(tw_day_list_size)    
-        group_info_list = []
-        for j in range(group_duplicate_tw_day_size): 
-            first={}
-            first = {"date": data[data["screen_name"]==group_duplicates[i][0]]["tw_day_list"].iloc[0][j].isoformat()}
-            for k in range(len(group_duplicates[i])):
-                label_tw_profile= group_duplicates[i][k]
-                first[label_tw_profile] = {"Número de tweets por dia": data[data["screen_name"]==group_duplicates[i][k]]["tw_per_day_list"].iloc[0][j],
-                                        "Número de tweets por hora": data[data["screen_name"]==group_duplicates[i][k]]["tweets_hour_day_list"].iloc[0][j]}
-            group_info_list.append(first)
-        data_final["Group "+str(i)].append({
-            "data": group_info_list,
-            "group_duplicates": group_duplicates[i]
-        })
+            tw_day_list_size.append(len(data[data["screen_name"]==group_duplicates[i][j]]["tw_day_list"].iloc[0]))   
+            #Create a list with all the tweets
+            for v in range(len(data[data["screen_name"]==group_duplicates[i][j]]["close_duplicates"].iloc[0])):
+                if (data.iloc[i]["close_duplicates"][v]["screen_name"]) in group_duplicates[i]:
+                    similar_tw_list.append({"screen_name":data[data["screen_name"]==group_duplicates[i][j]]["close_duplicates"].iloc[0][v]["screen_name"],
+                                            "text":(data[data["screen_name"]==group_duplicates[i][j]]["close_duplicates"].iloc[0][v]["tw_match_tw"])})
+                    
+        text_similar_tw_list = []
+        if (len(similar_tw_list) !=0):
+            find=False 
+            for q in range(len(similar_tw_list[0]["text"])):
+                for o in range(1,len(similar_tw_list)):
+                    if (similar_tw_list[0]["text"][q] in similar_tw_list[o]["text"]):                  
+                      find= True
+                    else:
+                      find = False
+                date_list = []
+                if (find==True): 
+                    text_similar_tw_list.append(similar_tw_list[0]["text"][q])
+            if(len(text_similar_tw_list)!=0):
+                data_similar_tweets_list = []
+                for t in range(len(text_similar_tw_list)):
+                    date_similar_tw_profile = []
+                    for p in range(len(group_duplicates[i])):
+                        group_profile_df = data[data["screen_name"]==group_duplicates[i][p]]     
+                        date_profile = next(item for item in group_profile_df["text_date_dict"].iloc[0] if item["text"] == text_similar_tw_list[t])["date"].isoformat()
+                        date_similar_tw_profile.append({"screen_name": group_profile_df["screen_name"].iloc[0], "date":date_profile})
+                    data_similar_tweets = {"tweet": text_similar_tw_list[t]}
+                    data_similar_tweets["publishInfo"] = date_similar_tw_profile
+                    data_similar_tweets_list.append(data_similar_tweets) 
+
+                group_duplicate_tw_day_size =  min(tw_day_list_size)    
+                group_info_list = []
+                for j in range(group_duplicate_tw_day_size): 
+                    first={}
+                    first = {"date": data[data["screen_name"]==group_duplicates[i][0]]["tw_day_list"].iloc[0][j].isoformat()}
+                    for k in range(len(group_duplicates[i])):
+                        label_tw_profile= group_duplicates[i][k]
+                        first[label_tw_profile] = {"Número de tweets por dia": data[data["screen_name"]==group_duplicates[i][k]]["tw_per_day_list"].iloc[0][j],
+                                                "Número de tweets por hora": data[data["screen_name"]==group_duplicates[i][k]]["tweets_hour_day_list"].iloc[0][j]}
+                    group_info_list.append(first)
+
+                data_final["Group "+ str(number_group)]= []
+                data_final["Group "+str(number_group)].append({
+                    "data": group_info_list,
+                    "group_duplicates": group_duplicates[i],
+                    "data_tweet_similar": data_similar_tweets_list
+                })
+                number_group = number_group+1
+
     data_groups_duplicates = {}
     data_groups_duplicates["groups"] = data_final
     return data_groups_duplicates
@@ -1051,6 +1087,25 @@ def hour_days_tweets(df):
     df["tweets_hour_day_list"] = hour_days_tweets_list
     return df
 
+def text_date_tweets_dict(data):
+    data["text_date_dict"] = 0
+    dict_profile_list= []
+    for i in range(len(data)):
+        dict_profile = []
+        print(i)
+        for j in range(len(data.iloc[i]["tweet_date_days_list"])):
+            if (len(data.iloc[i]["tweet_date_days_list"])==1):
+                for k in range(len(data.iloc[i]["text_tweets_days_list"][0])):
+                    dict_profile.append({"text": data.iloc[i]["text_tweets_days_list"][0][k],
+                                     "date": data.loc[i]["tweet_date_days_list"][0][k]})
+            else:
+                for k in range(len(data.iloc[i]["text_tweets_days_list"][j])):
+                    dict_profile.append({"text": data.iloc[i]["text_tweets_days_list"][j][k],
+                                     "date": data.loc[i]["tweet_date_days_list"][j][k]})
+        dict_profile_list.append(dict_profile)
+    data["text_date_dict"] = dict_profile_list
+    return data 
+
 	
 def advanced_features(data):
     
